@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-25'; # DATE
+our $DATE = '2022-11-26'; # DATE
 our $DIST = 'App-MineralUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 
@@ -138,6 +138,7 @@ our @potassium_forms = (
         potassium_ratio => 1,
         summary => 'Elemental potassium, in milligrams',
     },
+    # note: unlike magnesium (MgCl hexahydrate), KCl and NaCl does not form hydrates
     {
         name => 'mg-k-chloride',
         potassium_ratio => 39.0983/74.5513, # 52.45%
@@ -194,6 +195,7 @@ our @sodium_forms = (
         sodium_ratio => 1,
         summary => 'Elemental sodium, in milligrams',
     },
+    # note: unlike magnesium (MgCl hexahydrate), KCl and NaCl does not form hydrates
     {
         name => 'mg-na-chloride',
         sodium_ratio => 22.989769/58.44, # 39.34%
@@ -276,6 +278,10 @@ _
             args=>{quantity=>'350 mg-mg-elem'},
             summary=>'If I want to supplement 350mg elemental magnesium, how much of each compound should we use? (This does not yet take bioavailability into account)',
         },
+        {
+            args=>{quantity=>'1000 mg-mg-chloride-hexahydrate', to_unit=>'mg-mg-elem'},
+            summary=>'How much elemental magnesium is in 1000mg (1g) of magnesium chloride powder in capsule form? The chloride is in the common hexahydrate form',
+        },
     ],
 };
 sub convert_magnesium_unit {
@@ -332,6 +338,18 @@ _
             args=>{quantity=>'1000 mg-k-elem', to_unit=>'mg-k-cl'},
             summary=>'How much of potassium chloride provides 1000 mg of elemental potassium?',
         },
+        {
+            args=>{quantity=>'1000 mg-k-chloride', to_unit=>'mg-k-chloride'},
+            summary=>'How much elemental potassium is in 1000mg (1g) of potassium chloride powder in capsule form?',
+        },
+        {
+            args=>{quantity=>'600 mg-k-chloride', to_unit=>'mg-k-elem'},
+            summary=>'A tablet supplement called KSR contains 600mg of potassium chloride; how much elemental potassium is that?',
+        },
+        {
+            args=>{quantity=>'4700 mg-k-elem', to_unit=>'mg-k-chloride'},
+            summary=>'Recommended daily intake (DV) of (elemental) potassium for adults and children 4 years or older is 4,700mg according to US FDA; how much is that equivalent to in KCl? Note that it is *NOT* recommended (and most probably dangerous) to take KCl supplement that much as potassium is contained in other sources too',
+        },
     ],
 };
 sub convert_potassium_unit {
@@ -439,7 +457,7 @@ App::MineralUtils - Utilities related to mineral supplements
 
 =head1 VERSION
 
-This document describes version 0.009 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2022-09-25.
+This document describes version 0.010 of App::MineralUtils (from Perl distribution App-MineralUtils), released on 2022-11-26.
 
 =head1 DESCRIPTION
 
@@ -674,16 +692,27 @@ Result:
      },
    ],
    {
-     "table.field_aligns"  => ["number", "left", "left"],
-     "table.fields"        => ["amount", "unit", "summary"],
      "table.field_formats" => [
-                                ["number", { precision => 3, thousands_sep => "" }],
+                                ["number", { thousands_sep => "", precision => 3 }],
                                 undef,
                                 undef,
                               ],
+     "table.fields"        => ["amount", "unit", "summary"],
+     "table.field_aligns"  => ["number", "left", "left"],
    },
  ]
 
+=item * How much elemental magnesium is in 1000mg (1g) of magnesium chloride powder in capsule form? The chloride is in the common hexahydrate form:
+
+ convert_magnesium_unit(
+   quantity => "1000 mg-mg-chloride-hexahydrate",
+   to_unit  => "mg-mg-elem"
+ );
+
+Result:
+
+ [200, "OK", 120, {}]
+
 =back
 
 If target unit is not specified, will show all known conversions.
@@ -696,8 +725,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<quantity> => I<str> (default: "1 mg")
 
+(No description)
+
 =item * B<to_unit> => I<str>
 
+(No description)
+
 
 =back
 
@@ -759,12 +792,12 @@ Result:
    ],
    {
      "table.fields"        => ["amount", "unit", "summary"],
-     "table.field_aligns"  => ["number", "left", "left"],
      "table.field_formats" => [
-                                ["number", { thousands_sep => "", precision => 3 }],
+                                ["number", { precision => 3, thousands_sep => "" }],
                                 undef,
                                 undef,
                               ],
+     "table.field_aligns"  => ["number", "left", "left"],
    },
  ]
 
@@ -776,6 +809,26 @@ Result:
 
  [200, "OK", 1908.39694656489, {}]
 
+=item * How much elemental potassium is in 1000mg (1g) of potassium chloride powder in capsule form?:
+
+ convert_potassium_unit(quantity => "1000 mg-k-chloride", to_unit => "mg-k-chloride");
+
+Result:
+
+ [200, "OK", 1000, {}]
+
+=item * A tablet supplement called KSR contains 600mg of potassium chloride; how much elemental potassium is that?:
+
+ convert_potassium_unit(quantity => "600 mg-k-chloride", to_unit => "mg-k-elem"); # -> [200, "OK", 314.4, {}]
+
+=item * Recommended daily intake (DV) of (elemental) potassium for adults and children 4 years or older is 4,700mg according to US FDA; how much is that equivalent to in KCl? Note that it is *NOT* recommended (and most probably dangerous) to take KCl supplement that much as potassium is contained in other sources too:
+
+ convert_potassium_unit(quantity => "4700 mg-k-elem", to_unit => "mg-k-chloride");
+
+Result:
+
+ [200, "OK", 8969.46564885496, {}]
+
 =back
 
 If target unit is not specified, will show all known conversions.
@@ -788,8 +841,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<quantity> => I<str> (default: "1 mg")
 
+(No description)
+
 =item * B<to_unit> => I<str>
 
+(No description)
+
 
 =back
 
@@ -850,13 +907,13 @@ Result:
      },
    ],
    {
-     "table.field_aligns"  => ["number", "left", "left"],
      "table.fields"        => ["amount", "unit", "summary"],
      "table.field_formats" => [
-                                ["number", { precision => 3, thousands_sep => "" }],
+                                ["number", { thousands_sep => "", precision => 3 }],
                                 undef,
                                 undef,
                               ],
+     "table.field_aligns"  => ["number", "left", "left"],
    },
  ]
 
@@ -880,8 +937,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<quantity> => I<str> (default: "1 mg")
 
+(No description)
+
 =item * B<to_unit> => I<str>
 
+(No description)
+
 
 =back
 
